namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<Efl_Ui_Image_Scale_Type>::type Image::scale_type_get() const
{
   Efl_Ui_Image_Scale_Type __return_value =  ::efl_ui_image_scale_type_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Ui_Image_Scale_Type>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Image::scale_type_set( ::efl::eolian::in_traits<Efl_Ui_Image_Scale_Type>::type scale_type) const
{
    ::efl_ui_image_scale_type_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Ui_Image_Scale_Type,  ::efl::eolian::in_traits<Efl_Ui_Image_Scale_Type>::type>(scale_type));
}
inline ::efl::eolian::return_traits<void>::type Image::scalable_get( ::efl::eolian::out_traits<bool>::type scale_up,  ::efl::eolian::out_traits<bool>::type scale_down) const
{
   Eina_Bool __out_param_scale_up = {};
   Eina_Bool __out_param_scale_down = {};
    ::efl_ui_image_scalable_get(this->_eo_ptr()
      , & __out_param_scale_up
      , & __out_param_scale_down);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<bool>::type, Eina_Bool>(scale_up, __out_param_scale_up);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<bool>::type, Eina_Bool>(scale_down, __out_param_scale_down);
}
inline ::efl::eolian::return_traits<void>::type Image::scalable_set( ::efl::eolian::in_traits<bool>::type scale_up,  ::efl::eolian::in_traits<bool>::type scale_down) const
{
    ::efl_ui_image_scalable_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(scale_up)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(scale_down));
}
inline ::efl::eolian::return_traits<void>::type Image::align_get( ::efl::eolian::out_traits<double>::type align_x,  ::efl::eolian::out_traits<double>::type align_y) const
{
   double __out_param_align_x = {};
   double __out_param_align_y = {};
    ::efl_ui_image_align_get(this->_eo_ptr()
      , & __out_param_align_x
      , & __out_param_align_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(align_x, __out_param_align_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(align_y, __out_param_align_y);
}
inline ::efl::eolian::return_traits<void>::type Image::align_set( ::efl::eolian::in_traits<double>::type align_x,  ::efl::eolian::in_traits<double>::type align_y) const
{
    ::efl_ui_image_align_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(align_x)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(align_y));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Image::icon_get() const
{
   const char * __return_value =  ::efl_ui_image_icon_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Image::icon_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type name) const
{
   Eina_Bool __return_value =  ::efl_ui_image_icon_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(name));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
} } 
namespace eo_cxx {
namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<Efl_Ui_Image_Scale_Type>::type Image::scale_type_get() const
{
   Efl_Ui_Image_Scale_Type __return_value =  ::efl_ui_image_scale_type_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Ui_Image_Scale_Type>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Image::scale_type_set( ::efl::eolian::in_traits<Efl_Ui_Image_Scale_Type>::type scale_type) const
{
    ::efl_ui_image_scale_type_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Ui_Image_Scale_Type,  ::efl::eolian::in_traits<Efl_Ui_Image_Scale_Type>::type>(scale_type));
}
inline ::efl::eolian::return_traits<void>::type Image::scalable_get( ::efl::eolian::out_traits<bool>::type scale_up,  ::efl::eolian::out_traits<bool>::type scale_down) const
{
   Eina_Bool __out_param_scale_up = {};
   Eina_Bool __out_param_scale_down = {};
    ::efl_ui_image_scalable_get(this->_eo_ptr()
      , & __out_param_scale_up
      , & __out_param_scale_down);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<bool>::type, Eina_Bool>(scale_up, __out_param_scale_up);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<bool>::type, Eina_Bool>(scale_down, __out_param_scale_down);
}
inline ::efl::eolian::return_traits<void>::type Image::scalable_set( ::efl::eolian::in_traits<bool>::type scale_up,  ::efl::eolian::in_traits<bool>::type scale_down) const
{
    ::efl_ui_image_scalable_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(scale_up)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(scale_down));
}
inline ::efl::eolian::return_traits<void>::type Image::align_get( ::efl::eolian::out_traits<double>::type align_x,  ::efl::eolian::out_traits<double>::type align_y) const
{
   double __out_param_align_x = {};
   double __out_param_align_y = {};
    ::efl_ui_image_align_get(this->_eo_ptr()
      , & __out_param_align_x
      , & __out_param_align_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(align_x, __out_param_align_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(align_y, __out_param_align_y);
}
inline ::efl::eolian::return_traits<void>::type Image::align_set( ::efl::eolian::in_traits<double>::type align_x,  ::efl::eolian::in_traits<double>::type align_y) const
{
    ::efl_ui_image_align_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(align_x)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(align_y));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Image::icon_get() const
{
   const char * __return_value =  ::efl_ui_image_icon_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Image::icon_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type name) const
{
   Eina_Bool __return_value =  ::efl_ui_image_icon_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(name));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline efl::ui::Image::operator ::efl::ui::Image() const { return *static_cast< ::efl::ui::Image const*>(static_cast<void const*>(this)); }
inline efl::ui::Image::operator ::efl::ui::Image&() { return *static_cast< ::efl::ui::Image*>(static_cast<void*>(this)); }
inline efl::ui::Image::operator ::efl::ui::Image const&() const { return *static_cast< ::efl::ui::Image const*>(static_cast<void const*>(this)); }
} } }

